<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.wpdispensary.com
 * @since      1.0.0
 *
 * @package    Wpd_Wooconnect
 * @subpackage Wpd_Wooconnect/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wpd_Wooconnect
 * @subpackage Wpd_Wooconnect/admin
 * @author     WP Dispensary <deviodigital@gmail.com>
 */
class Wpd_Wooconnect_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpd_Wooconnect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpd_Wooconnect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wpd-wooconnect-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpd_Wooconnect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpd_Wooconnect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wpd-wooconnect-admin.js', array( 'jquery' ), $this->version, false );

	}

}

/**
 * Add POP in WooCommerce payment gateways
 * @param $methods
 * @return array
 */
function add_pay_on_pickup( $methods ) {
    $methods[] = 'WC_Gateway_Pay_on_pickup';
    return $methods;
}
add_filter( 'woocommerce_payment_gateways', 'add_pay_on_pickup' );


/**
 * Hide Attributes data panel.
 */
function hide_attributes_data_panel( $tabs ) {
	$tabs['attribute']['class'][] = 'hide_if_wpdwc_flowers hide_if_variable_wpdwc_flowers';
	$tabs['shipping']['class'][]  = 'hide_if_wpdwc_flowers hide_if_variable_wpdwc_flowers';
	return $tabs;
}
add_filter( 'woocommerce_product_data_tabs', 'hide_attributes_data_panel' );

add_filter( 'woocommerce_product_tabs', 'woo_remove_product_tabs', 98 );
function woo_remove_product_tabs( $tabs ) {
 
    unset( $tabs['additional_information'] );   // Remove the additional information tab
 
    return $tabs;
}


/**
 * Flower Type metabox
 *
 * Adds the Flower Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_Flowers {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'flowers';
	var $SELECT_POST_LABEL = 'Flower';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Flower item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id'               => $this->field_id,
			'name'             => $this->field_name,
			'selected'         => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type'        => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_flowers'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Flowers();

/**
 * Concentrate Type metabox
 *
 * Adds the Concentrate Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_Concentrates {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'concentrates';
	var $SELECT_POST_LABEL = 'Concentrate';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Concentrate item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id'               => $this->field_id,
			'name'             => $this->field_name,
			'selected'         => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type'        => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_concentrates'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Concentrates();

/**
 * Edible Type metabox
 *
 * Adds the Edible Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_Edibles {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'edibles';
	var $SELECT_POST_LABEL = 'Edible';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Edible item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_edibles'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Edibles();

/**
 * Pre-Roll Type metabox
 *
 * Adds the Pre-Roll Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_PreRolls {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'prerolls';
	var $SELECT_POST_LABEL = 'Pre-Roll';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Pre-Roll item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_prerolls'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_PreRolls();

/**
 * Topical Type metabox
 *
 * Adds the Topical Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_Topicals {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'topicals';
	var $SELECT_POST_LABEL = 'Topical';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Topical item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_topicals'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Topicals();

/**
 * Grower Type metabox
 *
 * Adds the Grower Type metabox to all WooCommerce products
 *
 * @since    1.0.0
 */
class WPD_WooConnect_Growers {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'growers';
	var $SELECT_POST_LABEL = 'Grower';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Grower item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_growers'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Growers();

/**
 * Gear Type metabox
 *
 * Adds the Gear Type metabox to all WooCommerce products
 *
 * @since    2.2.0
 */
class WPD_WooConnect_Gear {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'gear';
	var $SELECT_POST_LABEL = 'Gear';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Gear item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$prerollflower = sanitize_text_field( $_POST['selected_gear'] );
			update_post_meta( $post_id, $this->meta_key, $prerollflower );
		}
	}
}
new WPD_WooConnect_Gear();

/**
 * Tinctures Type metabox
 *
 * Adds the Tinctures Type metabox to all WooCommerce products
 *
 * @since    2.2.0
 */
class WPD_WooConnect_Tinctures {
	var $FOR_POST_TYPE = 'product';
	var $SELECT_POST_TYPE = 'tinctures';
	var $SELECT_POST_LABEL = 'Tinctures';
	var $box_id;
	var $box_label;
	var $field_id;
	var $field_label;
	var $field_name;
	var $meta_key;
	function __construct() {
		add_action( 'admin_init', array( $this, 'admin_init' ) );
	}
	function admin_init() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_post' ), 10, 2 );
		$this->meta_key     = "_selected_{$this->SELECT_POST_TYPE}";
		$this->box_id       = "select-{$this->SELECT_POST_TYPE}-metabox";
		$this->field_id     = "selected_{$this->SELECT_POST_TYPE}";
		$this->field_name   = "selected_{$this->SELECT_POST_TYPE}";
		$this->box_label    = __( 'WP Dispensary Tinctures item', 'wp-dispensary' );
		$this->field_label  = __( "Choose {$this->SELECT_POST_LABEL}", 'wp-dispensary' );
	}
	/**
	 * Add meta boxes
	 */
	function add_meta_boxes() {
		add_meta_box(
			$this->box_id,
			$this->box_label,
			array( $this, 'select_box' ),
			$this->FOR_POST_TYPE,
			'side'
		);
	}
	function select_box( $post ) {
		$selected_post_id = get_post_meta( $post->ID, $this->meta_key, true );
		global $wp_post_types;
		$save_hierarchical = $wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical;
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = true;
		wp_dropdown_pages( array(
			'id' => $this->field_id,
			'name' => $this->field_name,
			'selected' => empty( $selected_post_id ) ? 0 : $selected_post_id,
			'post_type' => $this->SELECT_POST_TYPE,
			'show_option_none' => $this->field_label,
		));
		$wp_post_types[ $this->SELECT_POST_TYPE ]->hierarchical = $save_hierarchical;
	}
	/**
	 * Save post
	 */
	function save_post( $post_id, $post ) {
		if ( $post->post_type === $this->FOR_POST_TYPE && isset( $_POST[ $this->field_name ] ) ) {
			$selectedtincture = sanitize_text_field( $_POST['selected_tinctures'] );
			update_post_meta( $post_id, $this->meta_key, $selectedtincture );
		}
	}
}
new WPD_WooConnect_Tinctures();

/**
 * Add Action Hook
 *
 * @since       1.0.0
 */
add_action( 'wpd_pricingoutput_after', 'wpd_wooconnect_shop' );

function wpd_wooconnect_shop() {
?>

<?php if ( in_array( get_post_type(), array( 'flowers' ) ) ) {
	
	global $post;

	$flowerid = $post->ID;

	$args = array(
		'meta_key'       => '_selected_flowers',
		'meta_value'     => $flowerid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Flower ?>


<?php if ( in_array( get_post_type(), array( 'concentrates' ) ) ) {
	
	global $post;
	$concentrateid = $post->ID;

	$args = array(
		'meta_key' => '_selected_concentrates',
		'meta_value' => $concentrateid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Concentrate ?>


<?php if ( in_array( get_post_type(), array( 'edibles' ) ) ) {
	
	global $post;
	$edibleid = $post->ID;

	$args = array(
		'meta_key' => '_selected_edibles',
		'meta_value' => $edibleid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Edible ?>


<?php if ( in_array( get_post_type(), array( 'prerolls' ) ) ) {
	
	global $post;
	$flowerid = $post->ID;

	$args = array(
		'meta_key' => '_selected_prerolls',
		'meta_value' => $flowerid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Pre-Roll ?>


<?php if ( in_array( get_post_type(), array( 'topicals' ) ) ) {
	
	global $post;
	$topicalid = $post->ID;

	$args = array(
		'meta_key' => '_selected_topicals',
		'meta_value' => $topicalid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Topical ?>


<?php if ( in_array( get_post_type(), array( 'growers' ) ) ) {
	
	global $post;
	$flowerid = $post->ID;

	$args = array(
		'meta_key' => '_selected_growers',
		'meta_value' => $flowerid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Growers ?>

<?php if ( in_array( get_post_type(), array( 'gear' ) ) ) {
	
	global $post;

	$gearid = $post->ID;

	$args = array(
		'meta_key'       => '_selected_gear',
		'meta_value'     => $gearid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Gear ?>

<?php if ( in_array( get_post_type(), array( 'tinctures' ) ) ) {
	
	global $post;

	$tinctureid = $post->ID;

	$args = array(
		'meta_key'       => '_selected_tinctures',
		'meta_value'     => $tinctureid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :

	echo '<p class="wpd-wooconnect">';

	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";

	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) {} else { ?>
	<a href='<?php the_permalink(); ?>' class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // end is_in_stock()
	endwhile;

	echo '</p>';

	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>

<?php } // if Tincture ?>



<?php }

/**
 * Action hook for WP Dispensary shortcodes
 */
add_action( 'wpd_shortcode_inside_bottom', 'wooconnect_wpd_bottomshortcode' );

function wooconnect_wpd_bottomshortcode() { ?>

<?php if ( in_array( get_post_type(), array( 'flowers' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters( 'wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$flowerid = $post->ID;
	$args = array(
		'meta_key'       => '_selected_flowers',
		'meta_value'     => $flowerid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // flowers ?>

<?php if ( in_array( get_post_type(), array( 'concentrates' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters('wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$concentrateid = $post->ID;
	$args = array(
		'meta_key' => '_selected_concentrates',
		'meta_value' => $concentrateid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // concentrates ?>

<?php if ( in_array( get_post_type(), array( 'edibles' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters('wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$edibleid = $post->ID;
	$args = array(
		'meta_key' => '_selected_edibles',
		'meta_value' => $edibleid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // edibles ?>

<?php if ( in_array( get_post_type(), array( 'prerolls' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters('wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$prerollid = $post->ID;
	$args = array(
		'meta_key' => '_selected_prerolls',
		'meta_value' => $prerollid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // pre-rolls ?>

<?php if ( in_array( get_post_type(), array( 'topicals' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters('wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$topicalid = $post->ID;
	$args = array(
		'meta_key' => '_selected_topicals',
		'meta_value' => $topicalid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // topicals ?>

<?php if ( in_array( get_post_type(), array( 'growers' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters('wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$growerid = $post->ID;
	$args = array(
		'meta_key' => '_selected_growers',
		'meta_value' => $growerid,
		'post_type' => 'product',
		'posts_per_page' => -1
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata();
	?>
	
	</p>
<?php } // growers ?>

<?php if ( in_array( get_post_type(), array( 'gear' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters( 'wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$gearid = $post->ID;
	$args = array(
		'meta_key'       => '_selected_gear',
		'meta_value'     => $gearid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // gear ?>

<?php if ( in_array( get_post_type(), array( 'tinctures' ) ) ) { ?>
	<p class="wpd-productbuttons">

	<?php

	$viewbtntext = "View Details";
	$btntext     = apply_filters( 'wpdwc_view_details_button_text', $viewbtntext );
	$newviewbtn  = '<a href="'. get_permalink() .'" class="button wpd-connect-btn">' . $btntext . '</a>';

	echo apply_filters( 'wpdwc_view_details_button_link', $newviewbtn );

	?>

	<?php
	global $post;
	$tinctureid = $post->ID;
	$args = array(
		'meta_key'       => '_selected_tinctures',
		'meta_value'     => $tinctureid,
		'post_type'      => 'product',
		'posts_per_page' => 1,
		'order'          => 'ASC',
		'orderby'        => 'date'
	);
	$wpd_wooconnect = new WP_Query( $args );
	if ( $wpd_wooconnect->have_posts() ) :
	while ( $wpd_wooconnect->have_posts() ) : $wpd_wooconnect->the_post();

	$buybtntext = "Buy Now!";
	global $product;
	$productID = get_the_ID();
	//echo $prouctID;
	//echo get_post_meta( $productID, '_stock_status', true );
	if ( 'outofstock' === get_post_meta( $productID, '_stock_status', true ) ) { ?>
	<span class="wpd-wooconnect-outofstock">Out of Stock</span>
	<?php } else { ?>
	<a href="<?php the_permalink(); ?>" class="button wpd-connect-btn buy-now"><?php echo apply_filters( 'wpdwc_buy_now_button_text', $buybtntext ); ?></a>
	<?php
	} // outofstock
	endwhile;
	endif;

	// Reset Post Data
	wp_reset_postdata(); ?>
	</p>
<?php } // tinctures ?>


<?php }
