<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.wpdispensary.com
 * @since      1.0.0
 *
 * @package    Wpd_Wooconnect
 * @subpackage Wpd_Wooconnect/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wpd_Wooconnect
 * @subpackage Wpd_Wooconnect/public
 * @author     WP Dispensary <deviodigital@gmail.com>
 */
class Wpd_Wooconnect_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpd_Wooconnect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpd_Wooconnect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wpd-wooconnect-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpd_Wooconnect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpd_Wooconnect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wpd-wooconnect-public.js', array( 'jquery' ), $this->version, false );

	}

}

/**
 * Adding in the WP Dispensary WooConnect Details tab
 */
add_filter( 'woocommerce_product_tabs', 'wpd_wooconnect_details_tab' );
function wpd_wooconnect_details_tab( $tabs ) {
	
	// Adds the new tab
	$wp_dispensary_options = get_option( 'wp_dispensary_option_name' );
	if ( ! isset( $wp_dispensary_options['wpd_hide_details'] ) ) {
		$wpd_hide_details = '';
	} else {
		$wpd_hide_details = $wp_dispensary_options['wpd_hide_details'];
	}
	if ( 'wpd_hide_details' !== $wpd_hide_details ) {
		$tabs['product_details'] = array(
			'title' 	=> __( 'Details', 'wpd-wooconnect' ),
			'priority' 	=> 1,
			'callback' 	=> 'wpd_wooconnect_details_tab_content'
		);
	}

	return $tabs;

}
function wpd_wooconnect_details_tab_content() {

	// The new tab content
	
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_flowers', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_flowers', true ) ) {
		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'aroma', true ) ) {
			$wpdaroma = '<tr><td><span>Aromas:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'aroma', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdaroma = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'flavor', true ) ) {
			$wpdflavor = '<tr><td><span>Flavors:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'flavor', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdflavor = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'effect', true ) ) {
			$wpdeffect = '<tr><td><span>Effects:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'effect', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdeffect = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'symptom', true ) ) {
			$wpdsymptom = '<tr><td><span>Symptoms:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'symptom', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdsymptom = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'condition', true ) ) {
			$wpdcondition = '<tr><td><span>Conditions:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'condition', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdcondition = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'ingredients', true ) ) {
			$wpdingredients = '<tr><td><span>Ingredients:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'ingredients', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdingredients = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thc', true ) ) {
			$wpdthc = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thc', true ) .'%</td></tr>';
		} else {
			$wpdthc = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbd', true ) ) {
			$wpdcbd = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbd', true ) .'%</td></tr>';
		} else {
			$wpdcbd = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thcmg', true ) ) {
			$wpdthcmg = '<tr><td><span>THC mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thcmg', true ) .'</td></tr>';
		} else {
			$wpdthcmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdmg', true ) ) {
			$wpdcbdmg = '<tr><td><span>CBD mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdmg', true ) .'</td></tr>';
		} else {
			$wpdcbdmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thccbdservings', true ) ) {
			$wpdservings = '<tr><td><span>Servings:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thccbdservings', true ) .'</td></tr>';
		} else {
			$wpdservings = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_netweight', true ) ) {
			$wpdnetweight = '<tr><td><span>Net weight:</span></td><td>' . get_post_meta( $wpdwooconnect, '_netweight', true ) .'g</td></tr>';
		} else {
			$wpdnetweight = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thctopical', true ) ) {
			$wpdthctopical = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thctopical', true ) .'%</td></tr>';
		} else {
			$wpdthctopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdtopical', true ) ) {
			$wpdcbdtopical = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdtopical', true ) .'%</td></tr>';
		} else {
			$wpdcbdtopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_sizetopical', true ) ) {
			$wpdsizetopical = '<tr><td><span>Size:</span></td><td>' . get_post_meta( $wpdwooconnect, '_sizetopical', true ) .' (oz)</td></tr>';
		} else {
			$wpdsizetopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_seedcount', true ) ) {
			$wpdseedcount = '<tr><td><span>Seeds per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_seedcount', true ) .'</td></tr>';
		} else {
			$wpdseedcount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_clonecount', true ) ) {
			$wpdclonecount = '<tr><td><span>Clones per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_clonecount', true ) .'</td></tr>';
		} else {
			$wpdclonecount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$prerollflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdpreroll = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $prerollflower ) .'>'. get_the_title( $prerollflower ) .'</a></td></tr>';
		} else {
			$wpdpreroll = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$growerflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdgrower = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $growerflower ) .'>'. get_the_title( $growerflower ) .'</a></td></tr>';
		} else {
			$wpdgrower = '';
		}

		echo $wpdaroma . $wpdflavor . $wpdeffect . $wpdsymptom . $wpdcondition . $wpdthc . $wpdcbd . $wpdthcmg . $wpdcbdmg . $wpdservings . $wpdnetweight . $wpdthctopical . $wpdcbdtopical . $wpdsizetopical . $wpdseedcount . $wpdclonecount . $wpdpreroll . $wpdgrower;

		echo '</table>';
	}
	// Reset Post Data
	wp_reset_postdata();


	/*
	 * Concentrates Details
	 */
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_concentrates', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_concentrates', true ) ) {
		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'aroma', true ) ) {
			$wpdaroma = '<tr><td><span>Aromas:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'aroma', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdaroma = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'flavor', true ) ) {
			$wpdflavor = '<tr><td><span>Flavors:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'flavor', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdflavor = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'effect', true ) ) {
			$wpdeffect = '<tr><td><span>Effects:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'effect', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdeffect = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'symptom', true ) ) {
			$wpdsymptom = '<tr><td><span>Symptoms:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'symptom', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdsymptom = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'condition', true ) ) {
			$wpdcondition = '<tr><td><span>Conditions:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'condition', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdcondition = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'ingredients', true ) ) {
			$wpdingredients = '<tr><td><span>Ingredients:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'ingredients', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdingredients = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thc', true ) ) {
			$wpdthc = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thc', true ) .'%</td></tr>';
		} else {
			$wpdthc = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbd', true ) ) {
			$wpdcbd = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbd', true ) .'%</td></tr>';
		} else {
			$wpdcbd = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thcmg', true ) ) {
			$wpdthcmg = '<tr><td><span>THC mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thcmg', true ) .'</td></tr>';
		} else {
			$wpdthcmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdmg', true ) ) {
			$wpdcbdmg = '<tr><td><span>CBD mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdmg', true ) .'</td></tr>';
		} else {
			$wpdcbdmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thccbdservings', true ) ) {
			$wpdservings = '<tr><td><span>Servings:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thccbdservings', true ) .'</td></tr>';
		} else {
			$wpdservings = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_netweight', true ) ) {
			$wpdnetweight = '<tr><td><span>Net weight:</span></td><td>' . get_post_meta( $wpdwooconnect, '_netweight', true ) .'g</td></tr>';
		} else {
			$wpdnetweight = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thctopical', true ) ) {
			$wpdthctopical = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thctopical', true ) .'%</td></tr>';
		} else {
			$wpdthctopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdtopical', true ) ) {
			$wpdcbdtopical = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdtopical', true ) .'%</td></tr>';
		} else {
			$wpdcbdtopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_sizetopical', true ) ) {
			$wpdsizetopical = '<tr><td><span>Size:</span></td><td>' . get_post_meta( $wpdwooconnect, '_sizetopical', true ) .' (oz)</td></tr>';
		} else {
			$wpdsizetopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_seedcount', true ) ) {
			$wpdseedcount = '<tr><td><span>Seeds per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_seedcount', true ) .'</td></tr>';
		} else {
			$wpdseedcount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_clonecount', true ) ) {
			$wpdclonecount = '<tr><td><span>Clones per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_clonecount', true ) .'</td></tr>';
		} else {
			$wpdclonecount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$prerollflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdpreroll = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $prerollflower ) .'>'. get_the_title( $prerollflower ) .'</a></td></tr>';
		} else {
			$wpdpreroll = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$growerflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdgrower = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $growerflower ) .'>'. get_the_title( $growerflower ) .'</a></td></tr>';
		} else {
			$wpdgrower = '';
		}

		echo $wpdaroma . $wpdflavor . $wpdeffect . $wpdsymptom . $wpdcondition . $wpdthc . $wpdcbd . $wpdthcmg . $wpdcbdmg . $wpdservings . $wpdnetweight . $wpdthctopical . $wpdcbdtopical . $wpdsizetopical . $wpdseedcount . $wpdclonecount . $wpdpreroll . $wpdgrower;

		echo '</table>';

	}		
	// Reset Post Data
	wp_reset_postdata();


	/**
	 * Edibles Details
	 */
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_edibles', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_edibles', true ) ) {
		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'ingredients', true ) ) {
			$wpdingredients = '<tr><td><span>Ingredients:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'ingredients', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdingredients = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thc', true ) ) {
			$wpdthc = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thc', true ) .'%</td></tr>';
		} else {
			$wpdthc = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbd', true ) ) {
			$wpdcbd = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbd', true ) .'%</td></tr>';
		} else {
			$wpdcbd = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thcmg', true ) ) {
			$wpdthcmg = '<tr><td><span>THC mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thcmg', true ) .'</td></tr>';
		} else {
			$wpdthcmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdmg', true ) ) {
			$wpdcbdmg = '<tr><td><span>CBD mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdmg', true ) .'</td></tr>';
		} else {
			$wpdcbdmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thccbdservings', true ) ) {
			$wpdservings = '<tr><td><span>Servings:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thccbdservings', true ) .'</td></tr>';
		} else {
			$wpdservings = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_netweight', true ) ) {
			$wpdnetweight = '<tr><td><span>Net weight:</span></td><td>' . get_post_meta( $wpdwooconnect, '_netweight', true ) .'g</td></tr>';
		} else {
			$wpdnetweight = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thctopical', true ) ) {
			$wpdthctopical = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thctopical', true ) .'%</td></tr>';
		} else {
			$wpdthctopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdtopical', true ) ) {
			$wpdcbdtopical = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdtopical', true ) .'%</td></tr>';
		} else {
			$wpdcbdtopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_sizetopical', true ) ) {
			$wpdsizetopical = '<tr><td><span>Size:</span></td><td>' . get_post_meta( $wpdwooconnect, '_sizetopical', true ) .' (oz)</td></tr>';
		} else {
			$wpdsizetopical = '';
		}

		echo $wpdingredients . $wpdthc . $wpdcbd . $wpdthcmg . $wpdcbdmg . $wpdservings . $wpdnetweight . $wpdthctopical . $wpdcbdtopical . $wpdsizetopical . $wpdseedcount . $wpdclonecount . $wpdpreroll . $wpdgrower;

		echo '</table>';
		
	}		
	// Reset Post Data
	wp_reset_postdata();


	/**
	 * Pre-Rolls Details
	 */
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_prerolls', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_prerolls', true ) ) {
		echo '<h2>'. $my_post->post_title . ' Details</h2>';
		
		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$prerollflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdpreroll = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $prerollflower ) .'>'. get_the_title( $prerollflower ) .'</a></td></tr>';
		} else {
			$wpdpreroll = '';
		}

		echo $wpdpreroll;

		echo '</table>';
	}
	// Reset Post Data
	wp_reset_postdata();

	/**
	 * Topicals Details
	 */
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_topicals', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_topicals', true ) ) {

		echo '<h2>'. $my_post->post_title . ' Details</h2>';

		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'ingredients', true ) ) {
			$wpdingredients = '<tr><td><span>Ingredients:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'ingredients', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdingredients = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thc', true ) ) {
			$wpdthc = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thc', true ) .'%</td></tr>';
		} else {
			$wpdthc = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbd', true ) ) {
			$wpdcbd = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbd', true ) .'%</td></tr>';
		} else {
			$wpdcbd = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thcmg', true ) ) {
			$wpdthcmg = '<tr><td><span>THC mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thcmg', true ) .'</td></tr>';
		} else {
			$wpdthcmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdmg', true ) ) {
			$wpdcbdmg = '<tr><td><span>CBD mg per serving:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdmg', true ) .'</td></tr>';
		} else {
			$wpdcbdmg = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thccbdservings', true ) ) {
			$wpdservings = '<tr><td><span>Servings:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thccbdservings', true ) .'</td></tr>';
		} else {
			$wpdservings = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_netweight', true ) ) {
			$wpdnetweight = '<tr><td><span>Net weight:</span></td><td>' . get_post_meta( $wpdwooconnect, '_netweight', true ) .'g</td></tr>';
		} else {
			$wpdnetweight = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_thctopical', true ) ) {
			$wpdthctopical = '<tr><td><span>THC:</span></td><td>' . get_post_meta( $wpdwooconnect, '_thctopical', true ) .'%</td></tr>';
		} else {
			$wpdthctopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_cbdtopical', true ) ) {
			$wpdcbdtopical = '<tr><td><span>CBD:</span></td><td>' . get_post_meta( $wpdwooconnect, '_cbdtopical', true ) .'%</td></tr>';
		} else {
			$wpdcbdtopical = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_sizetopical', true ) ) {
			$wpdsizetopical = '<tr><td><span>Size:</span></td><td>' . get_post_meta( $wpdwooconnect, '_sizetopical', true ) .' (oz)</td></tr>';
		} else {
			$wpdsizetopical = '';
		}

		echo $wpdthc . $wpdcbd . $wpdthcmg . $wpdcbdmg . $wpdservings . $wpdnetweight . $wpdthctopical . $wpdcbdtopical . $wpdsizetopical;

		echo '</table>';
		
	}
	// Reset Post Data
	wp_reset_postdata();


	/**
	 * Growers Details
	 */ 
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_growers', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_growers', true ) ) {
		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';
		/**
		 * Setting up WP Dispensary menu item data
		 */

		if ( get_post_meta( $wpdwooconnect, '_seedcount', true ) ) {
			$wpdseedcount = '<tr><td><span>Seeds per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_seedcount', true ) .'</td></tr>';
		} else {
			$wpdseedcount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_clonecount', true ) ) {
			$wpdclonecount = '<tr><td><span>Clones per unit:</span></td><td>' . get_post_meta( $wpdwooconnect, '_clonecount', true ) .'</td></tr>';
		} else {
			$wpdclonecount = '';
		}

		if ( get_post_meta( $wpdwooconnect, '_selected_flowers', true ) ) {
			$growerflower = get_post_meta( $wpdwooconnect, '_selected_flowers', true );
			$wpdgrower = '<tr><td><span>Flower:</span></td><td><a href='. get_permalink( $growerflower ) .'>'. get_the_title( $growerflower ) .'</a></td></tr>';
		} else {
			$wpdgrower = '';
		}

		echo $wpdseedcount . $wpdclonecount . $wpdgrower;

		echo '</table>';
	}
	// Reset Post Data
	wp_reset_postdata();


	/**
	 * Gear Details
	 */ 
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_gear', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_gear', true ) ) {

		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';

		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'vendor', true ) ) {
			$wpdvendors = '<tr><td><span>Vendor:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'vendor', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdvendors = '';
		}

		echo $wpdvendors;

		echo '</table>';
	}
	// Reset Post Data
	wp_reset_postdata();

	/**
	 * Tinctures Details
	 */ 
	global $post;
	$wpdwooconnect = get_post_meta( $post->ID, '_selected_tinctures', true );

	$my_post = get_post( $wpdwooconnect );
	
	if ( get_post_meta( $post->ID, '_selected_tinctures', true ) ) {

		echo '<h2>'. $my_post->post_title . ' Details</h2>';
	
		echo '<table class="wpdispensary-table single wpd-wooconnect">';

		/**
		 * Setting up WP Dispensary menu item data
		 */
		if ( get_the_term_list( $wpdwooconnect, 'ingredients', true ) ) {
			$wpdingredients = '<tr><td><span>Ingredients:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'ingredients', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdingredients = '';
		}

		if ( get_the_term_list( $wpdwooconnect, 'vendor', true ) ) {
			$wpdvendors = '<tr><td><span>Vendor:</span></td><td>' . get_the_term_list( $wpdwooconnect, 'vendor', '', ', ', '' ) . '</td></tr>';
		} else {
			$wpdvendors = '';
		}

		echo $wpdingredients . $wpdvendors;

		echo '</table>';
	}
	// Reset Post Data
	wp_reset_postdata();

}