<?php

/**
 * The plugin bootstrap file
 *
 * @link			  https://www.wpdispensary.com
 * @since			  1.0.0
 * @package		      WPD_WooConnect
 *
 * @wordpress-plugin
 * 
 * Plugin Name:	      WP Dispensary's Connect for WooCommece
 * Plugin URI:        https://www.wpdispensary.com/downloads/wooconnect-for-woocommerce
 * Description:       Connect your WP Dispensary menu to WooCommerce and accept orders directly through your website.
 * Version:           2.3.0
 * Author:            WP Dispensary
 * Author URI:        https://www.wpdispensary.com
 * WC tested up to:   3.3.3
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wpd-wooconnect
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wpd-wooconnect-activator.php
 */
function activate_wpd_wooconnect() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpd-wooconnect-activator.php';
	Wpd_Wooconnect_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wpd-wooconnect-deactivator.php
 */
function deactivate_wpd_wooconnect() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wpd-wooconnect-deactivator.php';
	Wpd_Wooconnect_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wpd_wooconnect' );
register_deactivation_hook( __FILE__, 'deactivate_wpd_wooconnect' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wpd-wooconnect.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since	1.0.0
 */
function run_wpd_wooconnect() {

	$plugin = new Wpd_Wooconnect();
	$plugin->run();

}
run_wpd_wooconnect();

require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

global $wpd_wooconnect_page, $wpd_wooconnect_req, $wpd_wooconnect_error, $wufdc_dir, $ufdc_custom, $wufdc_pro_file, $eufdc_data, $wpd_wooconnect_error_default;

$wpd_wooconnect_error_default = 'Please choose a file to upload!';
$wpd_wooconnect_page          = get_option( 'wpd_wooconnect_page' );
$wpd_wooconnect_req           = (get_option( 'wpd_wooconnect_req' )*1);
$wufdc_dir                    = plugin_dir_path( __FILE__ );
$eufdc_data                   = get_plugin_data(__FILE__);
$wpd_wooconnect_error         = trim( get_option( 'wpd_wooconnect_error' ) );
$wpd_wooconnect_error         = ( $wpd_wooconnect_error!=''?$wpd_wooconnect_error:$wpd_wooconnect_error_default );

include('inc/functions.php');
	
function eufdc_backup_pro($src='pro', $dst='') { 

	$plugin_dir = plugin_dir_path( __FILE__ );
	$uploads = wp_upload_dir();
	$dst = ( $dst!=''?$dst:$uploads['basedir'] );
	$src = ( $src=='pro'?$plugin_dir.$src:$src );
	
	$pro_check = basename( $plugin_dir );

	$pro_check = $dst.'/'.$pro_check.'.dat';

	if( file_exists( $pro_check ) ){
		if( !is_dir( $plugin_dir.'pro' ) ){
			mkdir( $plugin_dir.'pro' );
		}
		$files = file_get_contents( $pro_check );
		$files = explode( '\n', $files );
		if( !empty( $files ) ){
			foreach( $files as $file ){
				
				if( $file!='' ){
					
					$file_src = $uploads['basedir'].'/'.$file;
					//echo $file_src.' > '.$plugin_dir.'pro/'.$file.'<br />';
					$file_trg = $plugin_dir.'pro/'.$file;
					if( !file_exists( $file_trg ) )
					copy( $file_src, $file_trg );
				}
			}//exit;
		}
	}
	
	if( is_dir( $src ) ){
		if( !file_exists( $pro_check ) ){
			$f = fopen( $pro_check, 'w' );
			fwrite( $f, '' );
			fclose( $f );
		}	
		$dir = opendir( $src ); 
		@mkdir( $dst ); 
		while( false !== ( $file = readdir( $dir ) ) ) { 
			if ( ( $file != '.' ) && ( $file != '..' ) ) { 
				if ( is_dir( $src . '/' . $file ) ) { 
					eufdc_backup_pro( $src . '/' . $file, $dst . '/' . $file ); 
				} 
				else { 
					$dst_file = $dst . '/' . $file;
					
					if( !file_exists( $dst_file ) ){
						
						copy( $src . '/' . $file,$dst_file ); 
						$f = fopen( $pro_check, 'a+' );
						fwrite( $f, $file.'\n' );
						fclose( $f );
					}
				} 
			} 
		} 
		closedir( $dir ); 
		
	}	
}
	
function eufdc_activate() {	
	eufdc_backup_pro();
}
register_activation_hook( __FILE__, 'eufdc_activate' );

require_once( 'admin/ufdc-settings.php' );

add_action( 'admin_menu', 'wpd_wooconnect_admin_menu' );
add_action( 'init', 'ufdc_custom_file_upload' );						
//add_action('woocommerce_checkout_process', 'ufdc_custom_file_upload'); 

switch( $wpd_wooconnect_page ){
	
	case 'checkout':
		add_action( 'woocommerce_checkout_after_customer_details', 'add_file_to_upcoming_order' );
	break;
	
	case 'cart':
	case '':
		add_action( 'woocommerce_after_cart_table', 'add_file_to_upcoming_order' );
		add_action( 'wp_footer', 'ufdc_wpd_wooconnect_req' );
	break;
	
}

add_action( 'woocommerce_init', 'file_during_checkout');

add_action( 'woocommerce_order_status_pending', 'wc_checkout_order_processed' );
add_action( 'woocommerce_order_status_failed', 'wc_checkout_order_processed' );
add_action( 'woocommerce_order_status_on-hold', 'wc_checkout_order_processed' );
add_action( 'woocommerce_order_status_processing', 'wc_checkout_order_processed' );
add_action( 'woocommerce_order_status_completed', 'wc_checkout_order_processed' );
add_action( 'woocommerce_order_status_cancelled', 'wc_checkout_order_processed' );

add_action( 'save_post', 'pre_wc_checkout_order_processed' );

/**************************/

//add_action('woocommerce_order_status_pending', 'mysite_pending');
//add_action('woocommerce_order_status_failed', 'mysite_failed');
//add_action('woocommerce_order_status_on-hold', 'mysite_hold');
// Note that it's woocommerce_order_status_on-hold, not on_hold.
//add_action('woocommerce_order_status_processing', 'mysite_processing');
//add_action('woocommerce_order_status_completed', 'mysite_completed');
//add_action('woocommerce_order_status_refunded', 'mysite_refunded');
//add_action('woocommerce_order_status_cancelled', 'mysite_cancelled');	

/**************************/

add_action( 'init', 'init_sessions' );

add_action( 'add_meta_boxes', 'wpd_wooconnect_add_box' );

if( !is_admin() ) {
	add_action( 'wp_enqueue_scripts', 'wufdc_enqueue_style' );
	add_action( 'wp_enqueue_scripts', 'wufdc_enqueue_script' );
} else {
	$plugin = plugin_basename(__FILE__);
	add_action( 'admin_enqueue_scripts', 'wufdc_admin_enqueue_script' );
	add_filter( "plugin_action_links_$plugin", 'ufdc_plugin_links' );	
}

/**
 * Auto-add WooCommerce products when WPD Flower items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_flowers( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {
	  
	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'flowers_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$flowers_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_flowers', 'value' => $ID ) )
		)
	);

	while ( $flowers_query->have_posts() ) :

		$flowers_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editflowers = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$flowerid    = get_post_meta( $productid, '_selected_flowers', true );
	$flowerimage = get_post_meta( $flowerid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $flowerimage );

	/** Update the flower into the database */
	wp_update_post( $editflowers );

	/**
	 * Variation pricing
	 */
	$args = array(
		 'post_type'     => 'product_variation',
		 'post_status'   => array( 'private', 'publish' ),
		 'numberposts'   => -1,
		 'orderby'       => 'menu_order',
		 'order'         => 'asc',
		 'post_parent'   => $productid
	);
	$variations = get_posts( $args );

	foreach ( $variations as $variation ) {

		$flowerid = get_post_meta( $productid, '_selected_flowers', true ); // This is the ID of the product with the connection to the Flowers

		/** Variable wit the value set as the variation ID # */
		$variation_name = $variation->ID;

		/** Weight name */
		$weightname    = get_post_meta( $variation_name, 'attribute_pa_weight', true );

		/** Weight name defaults */
		$weightgram    = 'gram';
		$weighteighth  = 'eighth';
		$weightquarter = 'quarter';
		$weighthalf    = 'half';
		$weightounce   = 'ounce';

		/** Weight name variations */
		$wpdweightgram    = apply_filters( 'wpdwc_weight_gram', $weightgram );
		$wpdweighteighth  = apply_filters( 'wpdwc_weight_eighth', $weighteighth );
		$wpdweightquarter = apply_filters( 'wpdwc_weight_quarter', $weightquarter );
		$wpdweighthalf    = apply_filters( 'wpdwc_weight_half', $weighthalf );
		$wpdweightounce   = apply_filters( 'wpdwc_weight_ounce', $weightounce );

		/** Weight check - gram */
		if ( $wpdweightgram == $weightname ) {

			/** Get the gram price from the WPD item */
			$gramprice = get_post_meta( $flowerid, '_gram', true );

			/** Update the WooCommerce product with the gram price from WPD */
			update_post_meta( $variation_name, '_price', $gramprice );
			update_post_meta( $variation_name, '_regular_price', $gramprice );

		}

		/** Weight check - eighth */
		if ( $wpdweighteighth == $weightname ) {

			/** Get the eighth price from the WPD item */
			$eighthprice = get_post_meta( $flowerid, '_eighth', true );

			/** Update the WooCommerce product with the eighth price from WPD */
			update_post_meta( $variation_name, '_price', $eighthprice );
			update_post_meta( $variation_name, '_regular_price', $eighthprice );

		}

		/** Weight check - quarter */
		if ( $wpdweightquarter == $weightname ) {

			/** Get the gram price from the WPD item */
			$quarterprice = get_post_meta( $flowerid, '_quarter', true );

			/** Update the WooCommerce product with the quarter price from WPD */
			update_post_meta( $variation_name, '_price', $quarterprice );
			update_post_meta( $variation_name, '_regular_price', $quarterprice );

		}

		/** Weight check - half ounce */
		if ( $wpdweighthalf == $weightname ) {

			/** Get the gram price from the WPD item */
			$halfprice = get_post_meta( $flowerid, '_halfounce', true );

			/** Update the WooCommerce product with the half price from WPD */
			update_post_meta( $variation_name, '_price', $halfprice );
			update_post_meta( $variation_name, '_regular_price', $halfprice );

		}

		/** Weight check - ounce */
		if ( $wpdweightounce == $weightname ) {

			/** Get the gram price from the WPD item */
			$ounceprice = get_post_meta( $flowerid, '_ounce', true );

			/** Update the WooCommerce product with the ounce price from WPD */
			update_post_meta( $variation_name, '_price', $ounceprice );
			update_post_meta( $variation_name, '_regular_price', $ounceprice );

		}

	} // end foreach

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$category         = get_the_terms( $ID, 'flowers_category' );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$gramprice		= $_POST['_gram'];
	$eighthprice    = $_POST['_eighth'];
	$quarterprice   = $_POST['_quarter'];
	$halfprice      = $_POST['_halfounce'];
	$ounceprice     = $_POST['_ounce'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'            => wp_strip_all_tags( $title ),
		'post_content'          => $content,
		'post_status'           => 'publish',
		'post_author'           => $author,
		'post_type'             => 'product',
		'meta_input'            => array(
			'_selected_flowers' => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Flower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to variable
	wp_set_object_terms( $post_id, 'variable', 'product_type', true );

	//################### Add size attributes to main product: ####################
	//Array for setting attributes
	$avail_attributes = array(
		'ounce',
		'half',
		'quarter',
		'eighth',
		'gram'
	);
	wp_set_object_terms($post_id, $avail_attributes, 'pa_weight');

	$thedata = Array(
		'pa_weight' => Array(
			'name'		   =>'pa_weight',
			'value'		   =>'',
			'is_visible'   => '1', 
			'is_variation' => '1',
			'is_taxonomy'  => '1'
		)
	);
	update_post_meta( $post_id,'_product_attributes',$thedata);
	//########################## Done adding attributes to product #################

	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	//###################### Add Variation post types for sizes #############################
	//insert 5 variations post_types for ounce, half, quarter, eighth, gram:
	$i=1;
		while ( $i<=5 ) { //while creates 5 posts(1 for ea. size variation ounce, half etc):

		$my_post = array(
			'post_title'     => 'Variation #' . $i . ' of 5 for prdct#'. $post_id,
			'post_name'      => 'product-' . $post_id . '-variation-' . $i,
			'post_status'    => 'publish',
			'post_parent'    => $post_id,//post is a child post of product post
			'post_type'      => 'product_variation',//set post type to product_variation
			'guid'           => home_url() . '/?product_variation=product-' . $post_id . '-variation-' . $i
		);

		//Insert ea. post/variation into database:
		$attID   = wp_insert_post( $my_post );
		$logtxt .= "Attribute inserted with ID: $attID\n";

		//set IDs for product_variation posts:
		$variation_id    = $post_id + 1;
		$variation_two   = $variation_id + 1;
		$variation_three = $variation_two + 1;
		$variation_four  = $variation_three + 1;
		$variation_five  = $variation_four + 1;

		//Create ounce variation for ea product_variation:
		update_post_meta( $variation_id, 'attribute_pa_weight', 'ounce' );
		update_post_meta( $variation_id, '_price', $ounceprice );
		update_post_meta( $variation_id, '_regular_price', $ounceprice );
		//add size attributes to this variation:
		wp_set_object_terms( $variation_id, $avail_attributes, 'pa_weight' );
		$thedata = Array(
			'pa_weight' => Array(
				'name'         => $wpdweightounce,
				'value'        => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $variation_id,'_product_attributes',$thedata );

		//Create half variation for ea product_variation:
		update_post_meta( $variation_two, 'attribute_pa_weight', 'half' );
		update_post_meta( $variation_two, '_price', $halfprice );
		update_post_meta( $variation_two, '_regular_price', $halfprice );
		//add size attributes:
		wp_set_object_terms($variation_two, $avail_attributes, 'pa_weight');
		$thedata = Array(
			'pa_weight' => Array(
				'name'         => $wpdweighthalf,
				'value'        => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $variation_two,'_product_attributes',$thedata);
		
		//Create quarter variation for ea product_variation:
		update_post_meta( $variation_three, 'attribute_pa_weight', 'quarter' );
		update_post_meta( $variation_three, '_price', $quarterprice );
		update_post_meta( $variation_three, '_regular_price', $quarterprice );
		wp_set_object_terms($variation_three, $avail_attributes, 'pa_weight');
		$thedata = Array(
			'pa_weight' => Array(
				'name'         => $wpdweightquarter,
				'value'        => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $variation_three,'_product_attributes',$thedata);

		//Create eighth variation for ea product_variation:
		update_post_meta( $variation_four, 'attribute_pa_weight', 'eighth' );
		update_post_meta( $variation_four, '_price', $eighthprice );
		update_post_meta( $variation_four, '_regular_price', $eighthprice );
		wp_set_object_terms( $variation_four, $avail_attributes, 'pa_weight' );
		$thedata = Array(
			'pa_weight' => Array(
				'name'         => $wpdweighteighth,
				'value'        => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $variation_four,'_product_attributes',$thedata);

		//Create gram variation for each product_variation:
		update_post_meta( $variation_five, 'attribute_pa_weight', 'gram' );
		update_post_meta( $variation_five, '_price', $gramprice );
		update_post_meta( $variation_five, '_regular_price', $gramprice );
		wp_set_object_terms($variation_five, $avail_attributes, 'pa_weight' );
		$thedata = Array(
			'pa_weight' => Array(
				'name'         => $wpdweightgram,
				'value'        => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $variation_five,'_product_attributes',$thedata);

	$i++;
	}//end while i is less than or equal to 5(for 5 size variations)
	//############################ Done adding variation posts ############################

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published

}
add_action( 'publish_flowers', 'wpd_publish_wooconnect_flowers', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Concentrate items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_concentrates( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {
	  
	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'concentrates_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$concentrates_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_concentrates', 'value' => $ID ) )
		)
	);

	while ( $concentrates_query->have_posts() ) :

		$concentrates_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editconcentrates = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$concentrateid    = get_post_meta( $productid, '_selected_concentrates', true );
	$concentrateimage = get_post_meta( $concentrateid, '_thumbnail_id', true );

	/** Updated the featured image */
	update_post_meta( $productid, '_thumbnail_id', $concentrateimage );

	/** Update the concentrate into the database */
	wp_update_post( $editconcentrates );
	
	$wpdhalfgramprice = get_post_meta( $concentrateid, '_halfgram', true );
	$wpdgramprice     = get_post_meta( $concentrateid, '_gram', true );
	$wpdtwograms      = get_post_meta( $concentrateid, '_twograms', true );
	$wpdpriceeach     = get_post_meta( $concentrateid, '_priceeach', true );

	if ( '' !== $wpdpriceeach ) {

		wp_set_object_terms( $post_id, 'simple', 'product_type', true );
		update_post_meta( $post_id, '_price', $wpdpriceeach );
		update_post_meta( $post_id, '_regular_price', $wpdpriceeach );

	} else {

		/**
		 * Concentrates - Variable pricing
		 */
		$args = array(
			 'post_type'     => 'product_variation',
			 'post_status'   => array( 'private', 'publish' ),
			 'numberposts'   => -1,
			 'orderby'       => 'menu_order',
			 'order'         => 'asc',
			 'post_parent'   => $productid
		);
		$variations = get_posts( $args );

		foreach ( $variations as $variation ) {

			$concentrateid = get_post_meta( $productid, '_selected_concentrates', true ); // This is the ID of the product with the connection to the Flowers

			/** Variable wit the value set as the variation ID # */
			$variation_name = $variation->ID;

			/** Weight name */
			$weightname = get_post_meta( $variation_name, 'attribute_pa_weight', true );

			/** Weight name defaults */
			$weighthalfgram = 'halfgram';
			$weightgram     = 'gram';
			$weighttwograms = 'twograms';

			/** Weight name variations */
			$wpdweighthalfgram = apply_filters( 'wpdwc_weight_halfgram', $weighthalfgram );
			$wpdweightgram     = apply_filters( 'wpdwc_weight_gram', $weightgram );
			$wpdweighttwograms = apply_filters( 'wpdwc_weight_twograms', $weighttwograms );

			/** Weight check - halfgram */
			if ( $wpdweighthalfgram == $weightname ) {

				/** Get the gram price from the WPD item */
				$halfgramprice = get_post_meta( $concentrateid, '_halfgram', true );

				/** Update the WooCommerce product with the halfgram price from WPD */
				update_post_meta( $variation_name, '_price', $halfgramprice );
				update_post_meta( $variation_name, '_regular_price', $halfgramprice );

			}

			/** Weight check - gram */
			if ( $wpdweightgram == $weightname ) {

				/** Get the gram price from the WPD item */
				$gramprice = get_post_meta( $concentrateid, '_gram', true );

				/** Update the WooCommerce product with the gram price from WPD */
				update_post_meta( $variation_name, '_price', $gramprice );
				update_post_meta( $variation_name, '_regular_price', $gramprice );

			}

			/** Weight check - twograms */
			if ( $wpdweighttwograms == $weightname ) {

				/** Get the gram price from the WPD item */
				$twogramsprice = get_post_meta( $concentrateid, '_twograms', true );

				/** Update the WooCommerce product with the twograms price from WPD */
				update_post_meta( $variation_name, '_price', $twogramsprice );
				update_post_meta( $variation_name, '_regular_price', $twogramsprice );

			}

		} // end foreach

	}

  } else {


	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$category         = get_the_terms( $ID, 'concentrates_category' );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$halfgramprice  = $_POST['_halfgram'];
	$gramprice		= $_POST['_gram'];
	$twogramsprice  = $_POST['_twograms'];
	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_concentrates' => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Flower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	if ( '' !== $wpdpriceeach ) {

		// Set the product type to simple
		wp_set_object_terms( $post_id, 'simple', 'product_type', true );
		update_post_meta( $post_id, '_price', $wpdpriceeach );
		update_post_meta( $post_id, '_regular_price', $wpdpriceeach );
		//set product values:
		update_post_meta( $post_id, '_stock_status', 'instock');
		update_post_meta( $post_id, '_stock', "100" );
		update_post_meta( $post_id, '_visibility', 'visible' );

	} else {
		// Set the product type to variable
		wp_set_object_terms( $post_id, 'variable', 'product_type', true );

		//################### Add size attributes to main product: ####################
		//Array for setting attributes
		$avail_attributes = array(
			'twograms',
			'gram',
			'halfgram'
		);
		wp_set_object_terms($post_id, $avail_attributes, 'pa_weight');

		$thedata = Array(
			'pa_weight'=>Array(
				'name'		   => 'pa_weight',
				'value'		   => '',
				'is_visible'   => '1', 
				'is_variation' => '1',
				'is_taxonomy'  => '1'
			)
		);
		update_post_meta( $post_id,'_product_attributes',$thedata);
		//########################## Done adding attributes to product #################

		//set product values:
		update_post_meta( $post_id, '_stock_status', 'instock');
		update_post_meta( $post_id, '_stock', "100" );
		update_post_meta( $post_id, '_visibility', 'visible' );

		//###################### Add Variation post types for sizes #############################
		//insert 3 variations post_types for two grams, gram and half gram:
		$i=1;
			while ($i<=3) {//while creates 3 posts(1 for ea. size variation half gram, gram, etc):
			$my_post = array(
			'post_title'=> 'Variation #' . $i . ' of 3 for prdct#'. $post_id,
			'post_name' => 'product-' . $post_id . '-variation-' . $i,
			'post_status' => 'publish',
			'post_parent' => $post_id,//post is a child post of product post
			'post_type' => 'product_variation',//set post type to product_variation
			'guid'=>home_url() . '/?product_variation=product-' . $post_id . '-variation-' . $i
			);

			//Insert ea. post/variation into database:
			$attID = wp_insert_post( $my_post );
			$logtxt .= "Attribute inserted with ID: $attID\n";
			//set IDs for product_variation posts:
			$variation_id = $post_id + 1;
			$variation_two = $variation_id + 1;
			$variation_three = $variation_two + 1;

			//Create twograms variation for each product_variation:
			update_post_meta( $variation_id, 'attribute_pa_weight', 'twograms' );
			update_post_meta( $variation_id, '_price', $twogramsprice );
			update_post_meta( $variation_id, '_regular_price', $twogramsprice );
			//add size attributes to this variation:
			wp_set_object_terms( $variation_id, $avail_attributes, 'pa_weight' );
			$thedata = Array(
				'pa_weight'=>Array(
					'name'          => $wpdweighttwograms,
					'value'         => '',
					'is_visible'    => '1', 
					'is_variation'  => '1',
					'is_taxonomy'   => '1'
				)
			);
			update_post_meta( $variation_id,'_product_attributes',$thedata );

			//Create gram variation for each product_variation:
			update_post_meta( $variation_two, 'attribute_pa_weight', 'gram' );
			update_post_meta( $variation_two, '_price', $gramprice );
			update_post_meta( $variation_two, '_regular_price', $gramprice );
			wp_set_object_terms($variation_two, $avail_attributes, 'pa_weight' );
			$thedata = Array(
				'pa_weight' => Array(
					'name'          => $wpdweightgram,
					'value'         => '',
					'is_visible'    => '1', 
					'is_variation'  => '1',
					'is_taxonomy'   => '1'
				)
			);
			update_post_meta( $variation_two,'_product_attributes',$thedata);

			//Create halfgram variation for each product_variation:
			update_post_meta( $variation_three, 'attribute_pa_weight', 'halfgram' );
			update_post_meta( $variation_three, '_price', $halfgramprice );
			update_post_meta( $variation_three, '_regular_price', $halfgramprice );
			wp_set_object_terms($variation_three, $avail_attributes, 'pa_weight' );
			$thedata = Array(
				'pa_weight' => Array(
					'name'          => $wpdweighthalfgram,
					'value'         => '',
					'is_visible'    => '1', 
					'is_variation'  => '1',
					'is_taxonomy'   => '1'
				)
			);
			update_post_meta( $variation_three,'_product_attributes',$thedata);

		$i++;
		}//end while i is less than or equal to 3(for 3 size variations)
		//############################ Done adding variation posts ############################
	} // adds variable product

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_concentrates', 'wpd_publish_wooconnect_concentrates', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Edible items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_edibles( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'edibles_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$edibles_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_edibles', 'value' => $ID ) )
		)
	);

	while ( $edibles_query->have_posts() ) :

		$edibles_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editedibles = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$edibleid    = get_post_meta( $productid, '_selected_edibles', true );
	$edibleimage = get_post_meta( $edibleid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $edibleimage );

	/** Update the edible into the database */
	wp_update_post( $editedibles );

	/** Update the WooCommerce product with the gram price from WPD */
	$edibleprice = get_post_meta( $edibleid, '_priceeach', true );
	update_post_meta( $productid, '_price', $edibleprice );
	update_post_meta( $productid, '_regular_price', $edibleprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$category         = get_the_terms( $ID, 'edibles_category' );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_edibles'      => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Flower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_edibles', 'wpd_publish_wooconnect_edibles', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Pre-roll items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_prerolls( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'prerolls_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$prerolls_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_prerolls', 'value' => $ID ) )
		)
	);

	while ( $prerolls_query->have_posts() ) :

		$prerolls_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editprerolls = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$prerollid    = get_post_meta( $productid, '_selected_prerolls', true );
	$prerollimage = get_post_meta( $prerollid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $prerollimage );

	/** Update the preroll into the database */
	wp_update_post( $editprerolls );

	/** Update the WooCommerce product with the gram price from WPD */
	$prerollprice = get_post_meta( $prerollid, '_priceeach', true );
	update_post_meta( $productid, '_price', $prerollprice );
	update_post_meta( $productid, '_regular_price', $prerollprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_prerolls'     => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Flower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_prerolls', 'wpd_publish_wooconnect_prerolls', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Topical items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_topicals( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'topicals_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$topicals_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_topicals', 'value' => $ID ) )
		)
	);

	while ( $topicals_query->have_posts() ) :

		$topicals_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$edittopicals = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$topicalid    = get_post_meta( $productid, '_selected_topicals', true );
	$topicalimage = get_post_meta( $topicalid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $topicalimage );

	/** Update the topical into the database */
	wp_update_post( $edittopicals );

	/** Update the WooCommerce product with the gram price from WPD */
	$topicalprice = get_post_meta( $topicalid, '_pricetopical', true );
	update_post_meta( $productid, '_price', $topicalprice );
	update_post_meta( $productid, '_regular_price', $topicalprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'topicals_category' );
	$img_name         = strtolower( get_the_title( $ID ) );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_pricetopical'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_topicals'     => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Flower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_topicals', 'wpd_publish_wooconnect_topicals', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Growers items are published
 *
 * @since 2.0.0
 */
function wpd_publish_wooconnect_growers( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'growers_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$growers_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_growers', 'value' => $ID ) )
		)
	);

	while ( $growers_query->have_posts() ) :

		$growers_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editgrowers = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$growerid    = get_post_meta( $productid, '_selected_growers', true );
	$growerimage = get_post_meta( $growerid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $growerimage );

	/** Update the grower into the database */
	wp_update_post( $editgrowers );

	/** Update the WooCommerce product with the gram price from WPD */
	$growerprice = get_post_meta( $growerid, '_priceeach', true );
	update_post_meta( $productid, '_price', $growerprice );
	update_post_meta( $productid, '_regular_price', $growerprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'growers_category' );
	$img_name         = strtolower( get_the_title( $ID ) );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_growers'      => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Grower menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_growers', 'wpd_publish_wooconnect_growers', 10, 2 );



/**
 * Auto-add WooCommerce products when WPD Gear items are published
 *
 * @since 2.3.0
 */
function wpd_publish_wooconnect_gear( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'wpd_gear_category' );

	/** Query to get the ID # of the WooCommerce product that has the Flower selected */
	$gear_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_gear', 'value' => $ID ) )
		)
	);

	while ( $gear_query->have_posts() ) :

		$gear_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$editgear = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$gearid    = get_post_meta( $productid, '_selected_gear', true );
	$gearimage = get_post_meta( $gearid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $gearimage );

	/** Update the gear into the database */
	wp_update_post( $editgear );

	/** Update the WooCommerce product with the price from WPD */
	$gearprice = get_post_meta( $gearid, '_priceeach', true );
	update_post_meta( $productid, '_price', $gearprice );
	update_post_meta( $productid, '_regular_price', $gearprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$category         = get_the_terms( $ID, 'wpd_gear_category' );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents($image_url); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_gear'         => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Gear menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_gear', 'wpd_publish_wooconnect_gear', 10, 2 );


/**
 * Auto-add WooCommerce products when WPD Tincture items are published
 *
 * @since 2.3.0
 */
function wpd_publish_wooconnect_tinctures( $ID, $post ) {
	
  if ( $post->post_date != $post->post_modified ) {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = get_post_field( 'post_title', $ID );
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$category         = get_the_terms( $ID, 'wpd_tinctures_category' );

	/** Query to get the ID # of the WooCommerce product that has the Tincture selected */
	$tinctures_query = new WP_Query(
		array(
			'post_type'  => array( 'product' ),
			'meta_query' => array( array( 'key' => '_selected_tinctures', 'value' => $ID ) )
		)
	);

	while ( $tinctures_query->have_posts() ) :

		$tinctures_query->the_post();
		$productid = get_the_ID(); // This is the ID of the product with the connection to the Flowers

	endwhile;

	/** Data to send to wp_update_post */
	$edittinctures = array(
	  'ID'            => $productid, // this is the ID # of the WooCommerce product that needs to be updated
	  'post_title'    => wp_strip_all_tags( $title ),
	  'post_content'  => $content,
	);

	$tincturesid    = get_post_meta( $productid, '_selected_tinctures', true );
	$tincturesimage = get_post_meta( $tincturesid, '_thumbnail_id', true );

	update_post_meta( $productid, '_thumbnail_id', $tincturesimage );

	/** Update the tincture into the database */
	wp_update_post( $edittinctures );

	/** Update the WooCommerce product with the price from WPD */
	$tincturesprice = get_post_meta( $tincturesid, '_priceeach', true );
	update_post_meta( $productid, '_price', $tincturesprice );
	update_post_meta( $productid, '_regular_price', $tincturesprice );

  } else {

	/** Global */
	global $post;

	/** Variables */
	$author           = $post->post_author; /* Post author ID. */
	$title            = $post->post_title;
	$content          = get_post_field( 'post_content', $ID );
	$permalink        = get_permalink( $ID );
	$img_name         = strtolower( get_the_title( $ID ) );
	$category         = get_the_terms( $ID, 'wpd_tinctures_category' );
	$image_url        = get_the_post_thumbnail_url( $ID, 'full' ); // Define the image URL here
	$image_name       = $img_name . '.jpg';
	$upload_dir       = wp_upload_dir(); // Set upload folder
	$image_data       = file_get_contents( $image_url ); // Get image data
	$unique_file_name = wp_unique_filename( $upload_dir['path'], $image_name ); // Generate unique name
	$filename         = basename( $unique_file_name ); // Create image file name

	$priceeach      = $_POST['_priceeach'];

	// Check to see if category exists
	$cat_term = $cat->name;

	// Create category if it doesn't exist
	if ( !$cat_term ) {
		// foreach category names
		foreach ( $category as $cat ) {
			$categoryname = $cat->name;
			$cat_term = wp_insert_term( $categoryname, 'product_cat' );
		}
	}

	$my_post = array(
		'post_title'                 => wp_strip_all_tags( $title ),
		'post_content'               => $content,
		'post_status'                => 'publish',
		'post_author'                => $author,
		'post_type'                  => 'product',
		'meta_input'                 => array(
			'_selected_tinctures'    => $ID,
		)
	);

	// Insert the post into the database
	$post_id = wp_insert_post( $my_post );

	// Set the categories for the Tinctures menu type
	foreach ( $category as $cat_add ) {
		wp_set_object_terms( $post_id, $cat_add->name, 'product_cat', true );
	}

	// Set the product type to simple
	wp_set_object_terms( $post_id, 'simple', 'product_type', true );
	update_post_meta( $post_id, '_price', $priceeach );
	update_post_meta( $post_id, '_regular_price', $priceeach );
	//set product values:
	update_post_meta( $post_id, '_stock_status', 'instock');
	update_post_meta( $post_id, '_stock', "100" );
	update_post_meta( $post_id, '_visibility', 'visible' );

	/**
	 * Image Upload
	 */
	if ( $image_url != '' ) {
		// Check folder permission and define file location
		if( wp_mkdir_p( $upload_dir['path'] ) ) {
			$file = $upload_dir['path'] . '/' . $filename;
		} else {
			$file = $upload_dir['basedir'] . '/' . $filename;
		}

		// Create the image  file on the server
		file_put_contents( $file, $image_data );

		// Check image file type
		$wp_filetype = wp_check_filetype( $filename, null );

		// Set attachment data
		$attachment = array(
			'post_mime_type' => $wp_filetype['type'],
			'post_title'	 => sanitize_file_name( $filename ),
			'post_content'   => '',
			'post_status'	=> 'inherit'
		);

		// Create the attachment
		$attach_id = wp_insert_attachment( $attachment, $file, $post_id );

		// Include image.php
		require_once(ABSPATH . 'wp-admin/includes/image.php');

		// Define attachment metadata
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file );

		// Assign metadata to attachment
		wp_update_attachment_metadata( $attach_id, $attach_data );

		// And finally assign featured image to post
		set_post_thumbnail( $post_id, $attach_id );
	}
} // checking to see if the post has already been published
}
add_action( 'publish_tinctures', 'wpd_publish_wooconnect_tinctures', 10, 2 );



/**
 * Auto-update the inventory count when a sale is made in WooCommerce
 *
 * @since 2.0.0
 */
function wpdwc_inventory( $order_id  ) {

	$order  = new WC_Order( $order_id );
	$items  = $order->get_items();

	foreach ( $items as $item ) {

		$post_id = absint( $item['product_id'] );

		$stock_quantity = 0;

		$product_obj    = wc_get_product( $post_id );
		$stock_quantity = $product_obj->get_stock_quantity();

		/** If the product has a selected flower */
		if ( get_post_meta( $post_id, '_selected_flowers', true ) ) {

			/** Get the ID of the selected flower */
			$selected = get_post_meta( $post_id, '_selected_flowers', true );

			/** Update the inventory metabox for the selected flower with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_flowers', $stock_quantity );

		} // if _selected_flowers

		/** If the product has a selected concentrate */
		if ( get_post_meta( $post_id, '_selected_concentrates', true ) ) {

			/** Get the ID of the selected concentrate */
			$selected = get_post_meta( $post_id, '_selected_concentrates', true );

			/** Update the inventory metabox for the selected concentrate with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_concentrates', $stock_quantity );

		} // if _selected_concentrates

		/** If the product has a selected edible */
		if ( get_post_meta( $post_id, '_selected_edibles', true ) ) {

			/** Get the ID of the selected edible */
			$selected = get_post_meta( $post_id, '_selected_edibles', true );

			/** Update the inventory metabox for the selected edibles with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_edibles', $stock_quantity );

		} // if _selected_edibles

		/** If the product has a selected pre-roll */
		if ( get_post_meta( $post_id, '_selected_prerolls', true ) ) {

			/** Get the ID of the selected pre-roll */
			$selected = get_post_meta( $post_id, '_selected_prerolls', true );

			/** Update the inventory metabox for the selected pre-roll with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_prerolls', $stock_quantity );

		} // if _selected_prerolls

		/** If the product has a selected topical */
		if ( get_post_meta( $post_id, '_selected_topicals', true ) ) {

			/** Get the ID of the selected topical */
			$selected = get_post_meta( $post_id, '_selected_topicals', true );

			/** Update the inventory metabox for the selected topical with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_topicals', $stock_quantity );

		} // if _selected_topicals

		/** If the product has a selected grower */
		if ( get_post_meta( $post_id, '_selected_growers', true ) ) {

			/** Get the ID of the selected grower */
			$selected = get_post_meta( $post_id, '_selected_growers', true );

			/** Update the inventory metabox for the selected grower with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_growers', $stock_quantity );

		} // if _selected_growers

		/** If the product has a selected gear */
		if ( get_post_meta( $post_id, '_selected_gear', true ) ) {

			/** Get the ID of the selected gear */
			$selected = get_post_meta( $post_id, '_selected_gear', true );

			/** Update the inventory metabox for the selected gear with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_gear', $stock_quantity );

		} // if _selected_gear

		/** If the product has a selected tinctures */
		if ( get_post_meta( $post_id, '_selected_tinctures', true ) ) {

			/** Get the ID of the selected tincture */
			$selected = get_post_meta( $post_id, '_selected_tinctures', true );

			/** Update the inventory metabox for the selected tincture with the updated stock_quantity */
			update_post_meta( $selected, '_inventory_tinctures', $stock_quantity );

		} // if _selected_tinctures

	} // foreach

}
add_action( 'woocommerce_reduce_order_stock', 'wpdwc_inventory' );
